@@ -39,7 +39,7 @@ while (<FILE>)
               }
             elsif ($type eq "CMD")
               {
-                print `. /home/vdanjean/debian/mainteneur/taktuk/upstream/taktuk-svn/build/tests/functions.sh;if [ -r $ENV{srcdir}/local_functions.sh ]; \
+                print `. /Users/zebulon/Recherche/taktuk/trunk/tests/functions.sh;if [ -r $ENV{srcdir}/local_functions.sh ]; \
                        then . $ENV{srcdir}/local_functions.sh;fi;printf "%s " $line`;
               }
             elsif ($type eq "RAW")
