@@ -1,3 +1,6 @@
+TAKTUK_CONNECTOR='oarsh -o StrictHostKeyChecking=no -o BatchMode=yes'
+export TAKTUK_CONNECTOR
+
 get_hosts ()
   {
     if [ -n "$OAR_NODEFILE" ]
